pub struct UndistortedPixel<R: RealField + Copy> {
pub coords: Point2<R>,
}Expand description
A 2D pixel coordinate in the undistorted (rectified) image space.
This represents pixel coordinates after lens distortion has been removed, corresponding to an ideal pinhole camera model.
Fields
coords: Point2<R>The 2D pixel coordinates (x, y) in the undistorted image.