pub struct DistortedPixel<R: RealField + Copy> {
pub coords: Point2<R>,
}Expand description
A 2D pixel coordinate in the distorted image space.
This represents pixel coordinates as they appear in the raw camera image, including the effects of lens distortion.
Fields
coords: Point2<R>The 2D pixel coordinates (x, y) in the distorted image.
Implementations
Sourceimpl<R: RealField + Copy> DistortedPixel<R>
impl<R: RealField + Copy> DistortedPixel<R>
Sourcepub fn from_pixels<NPTS, IN>(pixels: &Pixels<R, NPTS, IN>, i: usize) -> Self
pub fn from_pixels<NPTS, IN>(pixels: &Pixels<R, NPTS, IN>, i: usize) -> Self
Extract a single distorted pixel from a collection of pixels.
This method allows you to extract one pixel coordinate from a larger collection of pixel coordinates, such as those returned by batch projection operations.
Arguments
pixels- A collection of pixel coordinatesi- The index of the pixel to extract (0-based)
Example
use braid_mvg::DistortedPixel;
use cam_geom::Pixels;
use nalgebra::{Point2, OMatrix, U2};
// This example would work with actual cam_geom::Pixels data
// let pixels = /* some cam_geom::Pixels instance */;
// let first_pixel = DistortedPixel::from_pixels(&pixels, 0);Trait Implementations
Sourceimpl<R: Clone + RealField + Copy> Clone for DistortedPixel<R>
impl<R: Clone + RealField + Copy> Clone for DistortedPixel<R>
Sourcefn clone(&self) -> DistortedPixel<R>
fn clone(&self) -> DistortedPixel<R>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R> From<&DistortedPixel<R>> for Pixels<R, U1, Owned<R, U1, U2>>
impl<R> From<&DistortedPixel<R>> for Pixels<R, U1, Owned<R, U1, U2>>
Sourcefn from(orig: &DistortedPixel<R>) -> Self
fn from(orig: &DistortedPixel<R>) -> Self
Converts to this type from the input type.